import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/area/vue';
import Select from '@opentinyvue/vue-select';
import Option from '@opentinyvue/vue-option';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "Area",
  components: {
    TinySelect: Select,
    TinyOption: Option
  },
  emits: ["update:modelValue", "change-office", "change-jcr", "change-region", "change-rep"],
  props: {
    modelValue: {
      type: Array,
      default: function _default() {
        return [];
      }
    },
    placeholder: {
      type: String,
      default: ""
    },
    size: String,
    disabled: {
      type: Boolean,
      default: false
    },
    props: {
      type: Object,
      default: function _default2() {
        return {
          label: "name_cn",
          value: "org_id"
        };
      }
    },
    fetchJcr: {
      type: Function
    },
    fetchRegion: {
      type: Function
    },
    fetchRep: {
      type: Function
    },
    fetchOffice: {
      type: Function
    },
    popperClass: String,
    popperAppendToBody: {
      type: Boolean,
      default: true
    }
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-area"
  }, [_c("tiny-select", _vm._b({
    ref: "refInstance",
    attrs: {
      "popper-class": "tiny-area-jcr" + (_vm.popperClass ? " " + _vm.popperClass : ""),
      "popper-append-to-body": _vm.popperAppendToBody,
      "size": _vm.size,
      "placeholder": _vm.placeholder,
      "disabled": _vm.disabled
    },
    on: {
      "change": _vm.getRegion,
      "clear": function clear($event) {
        return _vm.$emit("clear");
      },
      "visible-change": function visibleChange($event) {
        return _vm.$emit("visible-change", $event);
      }
    },
    model: {
      value: _vm.state.jcr,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "jcr", $$v);
      },
      expression: "state.jcr"
    }
  }, "tiny-select", _vm.a(_vm.$attrs, ["^on[A-Z]"]), false), _vm._l(_vm.state.jcrData, function(item) {
    return _c("tiny-option", {
      key: item[_vm.props.value],
      attrs: {
        "label": item[_vm.props.label],
        "value": item[_vm.props.value]
      }
    });
  }), 1), _c("tiny-select", _vm._b({
    attrs: {
      "popper-class": "tiny-area-region" + (_vm.popperClass ? " " + _vm.popperClass : ""),
      "popper-append-to-body": _vm.popperAppendToBody,
      "size": _vm.size,
      "placeholder": _vm.placeholder,
      "disabled": _vm.disabled
    },
    on: {
      "change": _vm.getRep,
      "clear": function clear($event) {
        return _vm.$emit("clear");
      },
      "visible-change": function visibleChange($event) {
        return _vm.$emit("visible-change", $event);
      }
    },
    model: {
      value: _vm.state.region,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "region", $$v);
      },
      expression: "state.region"
    }
  }, "tiny-select", _vm.a(_vm.$attrs, ["^on[A-Z]"]), false), _vm._l(_vm.state.regionData, function(item) {
    return _c("tiny-option", {
      key: item[_vm.props.value],
      attrs: {
        "label": item[_vm.props.label],
        "value": item[_vm.props.value]
      }
    });
  }), 1), _c("tiny-select", _vm._b({
    attrs: {
      "popper-class": "tiny-area-rep" + (_vm.popperClass ? " " + _vm.popperClass : ""),
      "popper-append-to-body": _vm.popperAppendToBody,
      "size": _vm.size,
      "placeholder": _vm.placeholder,
      "disabled": _vm.disabled
    },
    on: {
      "change": _vm.getOffice,
      "clear": function clear($event) {
        return _vm.$emit("clear");
      },
      "visible-change": function visibleChange($event) {
        return _vm.$emit("visible-change", $event);
      }
    },
    model: {
      value: _vm.state.rep,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "rep", $$v);
      },
      expression: "state.rep"
    }
  }, "tiny-select", _vm.a(_vm.$attrs, ["^on[A-Z]"]), false), _vm._l(_vm.state.repData, function(item) {
    return _c("tiny-option", {
      key: item[_vm.props.value],
      attrs: {
        "label": item[_vm.props.label],
        "value": item[_vm.props.value]
      }
    });
  }), 1), _c("tiny-select", _vm._b({
    attrs: {
      "popper-class": "tiny-area-office" + (_vm.popperClass ? " " + _vm.popperClass : ""),
      "popper-append-to-body": _vm.popperAppendToBody,
      "size": _vm.size,
      "placeholder": _vm.placeholder,
      "disabled": _vm.disabled
    },
    on: {
      "change": _vm.changeOffice,
      "clear": function clear($event) {
        return _vm.$emit("clear");
      },
      "visible-change": function visibleChange($event) {
        return _vm.$emit("visible-change", $event);
      }
    },
    model: {
      value: _vm.state.office,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "office", $$v);
      },
      expression: "state.office"
    }
  }, "tiny-select", _vm.a(_vm.$attrs, ["^on[A-Z]"]), false), _vm._l(_vm.state.officeData, function(item) {
    return _c("tiny-option", {
      key: item[_vm.props.value],
      attrs: {
        "label": item[_vm.props.label],
        "value": item[_vm.props.value]
      }
    });
  }), 1)], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
